#!/bin/bash
# called by _USER_ to perform the necessary updation
# perform the process of updating the files in the safesquid folder
# ACTION(s) performed : softlink, mkdir, copy with overwite, copy without overwrite
# OWNERSHIP and PERMISSIONS will also be set

set -o pipefail

CWD=`dirname $0`
IAM=`basename $0`
DIST=""
_USER_="ssquid"
_GROUP_="root"
OWNER="${_USER_}:${_GROUP_}"
_MONIT_STATUS=""
_MONIT=$(which monit) ; _e=$? ; [ "x${_e}" == "x0"  ] || _MONIT=""  
[ "x${_MONIT}" != "x" ] && ${_MONIT} status && let _MONIT_STATUS=0


[ "x${CWD}" == "x." ] && CWD=`pwd`

PARENT_DIR=`dirname ${CWD}`

LIST=${CWD}"/list.conf";
OLD_FILES=${CWD}"/old.conf";
LOGF="/tmp/setup.log";
DATE=`date`;
L=0;

LOG()
{
	echo "${DATE} - ${*}" 
}


MONIT_RESUME()
{
	[ "x${_MONIT_STATUS}" != "x0" ] && return;
	${_MONIT} reload
	${_MONIT} monitor all
	${_MONIT} validate
	${_MONIT} start all
}


DIE()
{
	START_SAFESQUID
	MONIT_RESUME
}


STOP_SAFESQUID ()
{
	[ -f "/etc/init.d/safesquid" ] && /etc/init.d/safesquid stop;
}

START_SAFESQUID ()
{
	[ ! -f "/etc/init.d/safesquid" ] && return;
	/etc/init.d/safesquid start;
}



WHICH_PLATFORM ()
{
	which aptitude && DIST="DB" && LOG "platform: Debian" && return;
	which apt-get && DIST="DB" && LOG "platform: Debian" && return;
	which yum && DIST="RH" && LOG "platform: Red-Hat" && return;
	DIE "platform: unknown"
}

MAKE_USER_ ()
{
	ID=""; 
	unset GID;
	typeset -a GID;
	unset G; typeset -i G; G=1
	
	useradd -r ${_USER_} -g ${_GROUP_} --shell ${SHELL}
	usermod ${_USER_} -g ${_GROUP_}
	ID=`id -un ${_USER_} 2> /dev/null` || DIE "cannot create _USER_: ${_USER_}"		
	GID=( `id -Gn ${_USER_} 2> /dev/null` ) || DIE "cannot check usergroup: ${_USER_}"

	for grps in ${GID[*]}
	do
		[ "x${grps}" != "x${_GROUP_}" ] && continue;			
		echo "_USER_ ${_USER_} is a member of _GROUP_ ${_GROUP_}" && G=0 && break;			
	done
	
	[ "x${G}" != "x0" ] && DIE "cannot add _USER_:${_USER_} to _GROUP_:${_GROUP_}"		
	
	return;
}


DEBIAN_INSTALLATION()
{	
	declare -a PACKS
	PACKS+=( `< ${CWD}/dependencies.lst` )
	PACKS+=( `< ${CWD}/system_dependnecies.lst` )
	
	if [ "x${PACKS}" != "x" ]; then
		export DEBIAN_FRONTEND=noninteractive
		aptitude -q -y install ${PACKS[*]}
		aptitude -y autoclean
		export DEBIAN_FRONTEND=
	fi	
}

REDHAT_INSTALLATION()
{	
	PACKS=`< ${CWD}/rh_dependencies.lst`	
	
	if [ "x${PACKS}" != "x" ]; then
		yum install ${PACKS}
	fi
}

INSTALL_PACKAGES()
{	
	[ "x${DIST}" == "x" ] && DIE "platform: unknown"
	[ "x${DIST}" == "xDB" ] && DEBIAN_INSTALLATION && return;
	[ "x${DIST}" == "xRH" ] && REDHAT_INSTALLATION && return;	
}

INSTALL_APPLIANCE ()
{
	rsync -av --exclude "installation" ${PARENT_DIR}/ /
}

READ_OLD()
{
	source ${OLD_FILES}
}

REMOVE_OLD()
{
	local i=0
	for (( i=0; i<${#OLD[*]}; i++))
	do
		[ "x${OLD[$i]}" == "x" ] && continue;
		[ ! -e  "${OLD[$i]}" ] && continue;
		rm -f "${OLD[$i]}"	
	done
}

MAIN()
{
	[ "x${_MONIT_STATUS}" == "x0" ] && ${_MONIT} unmonitor all

	WHICH_PLATFORM
	MAKE_USER_
	READ_OLD
	REMOVE_OLD
	INSTALL_PACKAGES
	STOP_SAFESQUID
	INSTALL_APPLIANCE
	START_SAFESQUID
}


> ${LOGF};

MAIN |& tee -a ${LOGF};
chown ${OWNER} ${LOGF}
DIE
